EXPORTS
	??0CApaDataRecognizer@@IAE@AAVRFs@@@Z @ 1 NONAME
	??0CApaDataRecognizerType@@IAE@VTUid@@H@Z @ 2 NONAME
	??0CApaScanningDataRecognizer@@IAE@AAVRFs@@@Z @ 3 NONAME
	??0TDataType@@QAE@ABV0@@Z @ 4 NONAME
	??0TDataType@@QAE@ABVTDesC8@@@Z @ 5 NONAME
	??0TDataType@@QAE@XZ @ 6 NONAME
	??1CApaDataRecognizer@@UAE@XZ @ 7 NONAME
	??1CApaDataRecognizerType@@UAE@XZ @ 8 NONAME
	??1CApaScanningDataRecognizer@@UAE@XZ @ 9 NONAME
	??8TDataType@@QBEHABV0@@Z @ 10 NONAME
	??9TDataType@@QBEHABV0@@Z @ 11 NONAME
	??ACApaScanningDataRecognizer@@QBEABVTRecognizer@0@H@Z @ 12 NONAME ; class CApaScanningDataRecognizer::TRecognizer const & CApaScanningDataRecognizer::operator[](int) const
	?AcceptedConfidence@CApaDataRecognizer@@QBEHXZ @ 13 NONAME ; int CApaDataRecognizer::AcceptedConfidence(void) const
	?AddDataRecognizerTypeL@CApaDataRecognizer@@IAEXPAVCApaDataRecognizerType@@@Z @ 14 NONAME
	?ConstructL@CApaScanningDataRecognizer@@IAEXXZ @ 15 NONAME
	?Des@TDataType@@QBE?AV?$TBuf@$0BAA@@@XZ @ 16 NONAME
	?DestroyRecognizerList@CApaDataRecognizer@@IAEXXZ @ 17 NONAME
	?DoRecognizeL@CApaDataRecognizerType@@EAEXABVTDesC16@@ABVTDesC8@@@Z @ 18 NONAME
	?ExternalizeL@TDataType@@QBEXAAVRWriteStream@@@Z @ 19 NONAME
	?InternalizeL@TDataType@@QAEXAAVRReadStream@@@Z @ 20 NONAME
	?Lock@CApaDataRecognizerType@@QAEXXZ @ 21 NONAME
	?MimeType@CApaDataRecognizerType@@QAE?AVTDataType@@XZ @ 22 NONAME
	?DataTypeL@CApaDataRecognizer@@QAEXAAV?$CArrayFixFlat@VTDataType@@@@@Z @ 23 NONAME
	?NewL@CApaScanningDataRecognizer@@SAPAV1@AAVRFs@@@Z @ 24 NONAME
	?PreferredBufSize@CApaDataRecognizer@@QBEHXZ @ 25 NONAME ; int CApaDataRecognizer::PreferredBufSize(void) const
	?PreferredBufSize@CApaDataRecognizerType@@UAEIXZ @ 26 NONAME
	?RecognizeL@CApaDataRecognizer@@QAE?AVTDataRecognitionResult@@ABVTDesC16@@ABVTDesC8@@@Z @ 27 NONAME
	?RecognizeL@CApaDataRecognizer@@QAEHABVTDesC16@@ABVTDesC8@@ABVTDataType@@@Z @ 28 NONAME
	?RecognizeL@CApaDataRecognizerType@@QAE?AVTDataRecognitionResult@@ABVTDesC16@@ABVTDesC8@@@Z @ 29 NONAME
	?RecognizerCount@CApaScanningDataRecognizer@@QAEHXZ @ 30 NONAME
	?RecognizerListLC@CApaScanningDataRecognizer@@QBEPAV?$CArrayFixFlat@VTRecognizer@CApaScanningDataRecognizer@@@@XZ @ 31 NONAME
	?RemoveDataRecognizerType@CApaDataRecognizer@@IAEHPBVCApaDataRecognizerType@@@Z @ 32 NONAME
	?Reserved_1@CApaDataRecognizerType@@EAEXXZ @ 33 NONAME
	?Reset@TDataRecognitionResult@@QAEXXZ @ 34 NONAME
	?ScanForRecognizersL@CApaScanningDataRecognizer@@QAEXXZ @ 35 NONAME
	?SetAcceptedConfidence@CApaDataRecognizer@@QAEXH@Z @ 36 NONAME
	?SetRecognizerL@CApaScanningDataRecognizer@@QAEXABVTRecognizer@1@@Z @ 37 NONAME ABSENT
	?SetRecognizersFromListL@CApaScanningDataRecognizer@@QAEXABV?$CArrayFixFlat@VTRecognizer@CApaScanningDataRecognizer@@@@@Z @ 38 NONAME ABSENT
	?Unlock@CApaDataRecognizerType@@QAEXXZ @ 39 NONAME
	?UpdateCounter@CApaScanningDataRecognizer@@QBEHXZ @ 40 NONAME
	?UpdateDataTypesL@CApaDataRecognizer@@QAEXXZ @ 41 NONAME
	?UpdateDataTypesL@CApaDataRecognizerType@@QAEXXZ @ 42 NONAME
	?Des8@TDataType@@QBE?AVTPtrC8@@XZ @ 43 NONAME
	??0TDataType@@QAE@VTUid@@@Z @ 44 NONAME
	??0TDataTypeWithPriority@@QAE@ABVTDataType@@J@Z @ 45 NONAME ; TDataTypeWithPriority::TDataTypeWithPriority(class TDataType const &, long)
	??0TMappingDataTypeToApp@@QAE@ABVTDataType@@JVTUid@@1@Z @ 46 NONAME ; TMappingDataTypeToApp::TMappingDataTypeToApp(class TDataType const &, long, class TUid, class TUid)
	??0TMappingDataTypeToApp@@QAE@XZ @ 47 NONAME
	??1CTypeStoreManager@@UAE@XZ @ 48 NONAME
	?DeleteDataMapping@CTypeStoreManager@@QAEXABVTDataType@@@Z @ 49 NONAME
	?ExternalizeL@CTypeStoreManager@@QBEXAAVRWriteStream@@@Z @ 50 NONAME
	?ExternalizeL@TMappingDataTypeToApp@@QBEXAAVRWriteStream@@@Z @ 51 NONAME
	?GetAppByDataType@CTypeStoreManager@@QBEXABVTDataType@@AAVTUid@@@Z @ 52 NONAME
	?GetDataTypesByAppL@CTypeStoreManager@@QBEXVTUid@@PAV?$CArrayFix@VTDataType@@@@@Z @ 53 NONAME
	?InsertDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@JVTUid@@1@Z @ 54 NONAME ; void CTypeStoreManager::InsertDataMappingL(class TDataType const &, long, class TUid, class TUid)
	?InsertIfHigherL@CTypeStoreManager@@QAEHABVTDataType@@JVTUid@@1@Z @ 55 NONAME ; int CTypeStoreManager::InsertIfHigherL(class TDataType const &, long, class TUid, class TUid)
	?InternalizeL@CTypeStoreManager@@QAEXAAVRReadStream@@@Z @ 56 NONAME
	?InternalizeL@TMappingDataTypeToApp@@QAEXAAVRReadStream@@@Z @ 57 NONAME
	?IsNative@TDataType@@QBEHXZ @ 58 NONAME
	?MappingArray@CTypeStoreManager@@QBEABV?$CArrayFixFlat@VTMappingDataTypeToApp@@@@XZ @ 59 NONAME
	?NewL@CTypeStoreManager@@SAPAV1@AAVRFs@@@Z @ 60 NONAME
	?RestoreL@CTypeStoreManager@@QAEXXZ @ 61 NONAME
	?StoreL@CTypeStoreManager@@QAEXXZ @ 62 NONAME
	?Uid@TDataType@@QBE?AVTUid@@XZ @ 63 NONAME
	?CApaDataRecognizer_Reserved_1@CApaDataRecognizer@@EAEXXZ @ 64 NONAME ; private: virtual void __thiscall CApaDataRecognizer::CApaDataRecognizer_Reserved_1(void)
	?CreateDataRecognizerL@CApaDataRecognizerType@@SAPAV1@VTUid@@@Z @ 65 NONAME ; public: static class CApaDataRecognizerType * __cdecl CApaDataRecognizerType::CreateDataRecognizerL(class TUid)
	?SetEcomRecognizerL@CApaScanningDataRecognizer@@QAEXABVTRecognizer@1@@Z @ 66 NONAME
	?SetEcomRecognizersFromListL@CApaScanningDataRecognizer@@QAEXABV?$CArrayFixFlat@VTRecognizer@CApaScanningDataRecognizer@@@@@Z @ 67 NONAME
	?RecognizeL@CApaDataRecognizer@@QAE?AVTDataRecognitionResult@@AAVRFile@@H@Z @ 68 NONAME ; class TDataRecognitionResult CApaDataRecognizer::RecognizeL(class RFile &)
	?RecognizeL@CApaDataRecognizer@@QAEHAAVRFile@@HABVTDataType@@@Z @ 69 NONAME ; int CApaDataRecognizer::RecognizeL(class RFile &, class TDataType const &)
	?FilePassedByHandleL@CApaDataRecognizerType@@IAEPAVRFile@@XZ @ 70 NONAME ; class RFile * CApaDataRecognizerType::FilePassedByHandleL()
	??0TDataTypeWithPriority@@QAE@XZ @ 71 NONAME ; TDataTypeWithPriority::TDataTypeWithPriority(void)
	?ExternalizeL@TDataTypeWithPriority@@QBEXAAVRWriteStream@@@Z @ 72 NONAME ; void TDataTypeWithPriority::ExternalizeL(class RWriteStream &) const
	?InternalizeL@TDataTypeWithPriority@@QAEXAAVRReadStream@@@Z @ 73 NONAME ; void TDataTypeWithPriority::InternalizeL(class RReadStream &)
	??0TMappingDataTypeToApp@@QAE@ABVTDataType@@JVTUid@@@Z @ 74 NONAME ; TMappingDataTypeToApp::TMappingDataTypeToApp(class TDataType const &, long, class TUid)
	?DeleteDataMapping@CTypeStoreManager@@QAEXABVTDataType@@VTUid@@@Z @ 75 NONAME ; void CTypeStoreManager::DeleteDataMapping(class TDataType const &, class TUid)
	?GetAppByDataType@CTypeStoreManager@@QBEXABVTDataType@@VTUid@@AAV3@@Z @ 76 NONAME ; void CTypeStoreManager::GetAppByDataType(class TDataType const &, class TUid, class TUid &) const
	?InsertDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@JVTUid@@@Z @ 77 NONAME ; void CTypeStoreManager::InsertDataMappingL(class TDataType const &, long, class TUid)
	?InsertIfHigherL@CTypeStoreManager@@QAEHABVTDataType@@JVTUid@@@Z @ 78 NONAME ; int CTypeStoreManager::InsertIfHigherL(class TDataType const &, long, class TUid)
	?InsertAndStoreDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@JVTUid@@1@Z @ 79 NONAME ; void CTypeStoreManager::InsertAndStoreDataMappingL(class TDataType const &, long, class TUid, class TUid)
	?InsertAndStoreDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@JVTUid@@@Z @ 80 NONAME ; void CTypeStoreManager::InsertAndStoreDataMappingL(class TDataType const &, long, class TUid)
	?InsertAndStoreIfHigherL@CTypeStoreManager@@QAEHABVTDataType@@JVTUid@@1@Z @ 81 NONAME ; int CTypeStoreManager::InsertAndStoreIfHigherL(class TDataType const &, long, class TUid, class TUid)
	?InsertAndStoreIfHigherL@CTypeStoreManager@@QAEHABVTDataType@@JVTUid@@@Z @ 82 NONAME ; int CTypeStoreManager::InsertAndStoreIfHigherL(class TDataType const &, long, class TUid)
	?DeleteAndStoreDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@@Z @ 83 NONAME ; void CTypeStoreManager::DeleteAndStoreDataMappingL(class TDataType const &)
	?DeleteAndStoreDataMappingL@CTypeStoreManager@@QAEXABVTDataType@@VTUid@@@Z @ 84 NONAME ; void CTypeStoreManager::DeleteAndStoreDataMappingL(class TDataType const &, class TUid)
	?LoadRecognizersL@CApaScanningDataRecognizer@@QAEXXZ @ 85 NONAME ; void CApaScanningDataRecognizer::LoadRecognizersL(void)
	?UnloadRecognizers@CApaScanningDataRecognizer@@QAEXXZ @ 86 NONAME ; void CApaScanningDataRecognizer::UnloadRecognizers(void)
	?NewL@CApaScanningDataRecognizer@@SAPAV1@AAVRFs@@H@Z @ 87 NONAME ; class CApaScanningDataRecognizer * CApaScanningDataRecognizer::NewL(class RFs &, int)
	?DeleteApplicationDataMappings@CTypeStoreManager@@QAEHVTUid@@@Z @ 88 NONAME ; int CTypeStoreManager::DeleteApplicationDataMappings(class TUid)

